package com.sundot.airport.blocked.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.sundot.airport.blocked.domain.BlockedBootPersonnelTenure;

/**
 * 开机人员年限分布Service接口
 *
 * @author ruoyi
 * @date 2026-04-16
 */
public interface IBlockedBootPersonnelTenureService extends IService<BlockedBootPersonnelTenure> {
    /**
     * 查询开机人员年限分布
     *
     * @param id 开机人员年限分布主键
     * @return 开机人员年限分布
     */
    public BlockedBootPersonnelTenure selectBlockedBootPersonnelTenureById(Long id);

    /**
     * 查询开机人员年限分布列表
     *
     * @param blockedBootPersonnelTenure 开机人员年限分布
     * @return 开机人员年限分布集合
     */
    public List<BlockedBootPersonnelTenure> selectBlockedBootPersonnelTenureList(BlockedBootPersonnelTenure blockedBootPersonnelTenure);

    /**
     * 新增开机人员年限分布
     *
     * @param blockedBootPersonnelTenure 开机人员年限分布
     * @return 结果
     */
    public int insertBlockedBootPersonnelTenure(BlockedBootPersonnelTenure blockedBootPersonnelTenure);

    /**
     * 修改开机人员年限分布
     *
     * @param blockedBootPersonnelTenure 开机人员年限分布
     * @return 结果
     */
    public int updateBlockedBootPersonnelTenure(BlockedBootPersonnelTenure blockedBootPersonnelTenure);

    /**
     * 批量删除开机人员年限分布
     *
     * @param ids 需要删除的开机人员年限分布主键集合
     * @return 结果
     */
    public int deleteBlockedBootPersonnelTenureByIds(Long[] ids);

    /**
     * 删除开机人员年限分布信息
     *
     * @param id 开机人员年限分布主键
     * @return 结果
     */
    public int deleteBlockedBootPersonnelTenureById(Long id);

    /**
     * 导入开机人员年限分布列表
     *
     * @param list          数据列表
     * @param updateSupport 是否更新支持
     * @return 导入结果信息
     */
    public String importData(List<BlockedBootPersonnelTenure> list, boolean updateSupport);
}
